@@ -14,7 +14,10 @@ import os, subprocess
 def coffee(app):
     @app.before_request
     def _render_coffee():
-        static_dir = app.root_path + app.static_path
+        try:
+            static_dir = app.root_path + app.static_url_path
+        except AttributeError, e:    
+            static_dir = app.root_path + app.static_path # < version 0.7
         
         coffee_paths = []
         for path, subdirs, filenames in os.walk(static_dir):
